<?php

namespace Litecms\Homepage\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Homepage\Models\Carousel;

class CarouselPolicy
{

    /**
     * Determine if the given user can view the carousel.
     *
     * @param UserPolicyInterface $authUser
     * @param Carousel $carousel
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Carousel $carousel)
    {
        if ($authUser->canDo('homepage.carousel.view') && $authUser->isAdmin()) {
            return true;
        }

        return $carousel->user_id == user_id() && $carousel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a carousel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('homepage.carousel.create');
    }

    /**
     * Determine if the given user can update the given carousel.
     *
     * @param UserPolicyInterface $authUser
     * @param Carousel $carousel
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Carousel $carousel)
    {
        if ($authUser->canDo('homepage.carousel.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $carousel->user_id == user_id() && $carousel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given carousel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Carousel $carousel)
    {
        return $carousel->user_id == user_id() && $carousel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given carousel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Carousel $carousel)
    {
        if ($authUser->canDo('homepage.carousel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given carousel.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Carousel $carousel)
    {
        if ($authUser->canDo('homepage.carousel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
